;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "daemons" "20250514.1107"
  "UI for managing init system daemons (services)."
  '((emacs  "25.1")
    (s      "1.13.0")
    (compat "29.1.4.2"))
  :url "https://github.com/cbowdon/daemons.el"
  :commit "7b08ce315c0be901d88c1099483f9607c653712e"
  :revdesc "7b08ce315c0b"
  :keywords '("unix" "convenience"))
